leaftools.fuse_leaves_in_tie_chain_by_immediate_parent_big_endian
=================================================================

.. autofunction:: abjad.tools.leaftools.fuse_leaves_in_tie_chain_by_immediate_parent_big_endian.fuse_leaves_in_tie_chain_by_immediate_parent_big_endian
